@@ -7,6 +7,10 @@ C*  J. R. M. HOSKING <jrmhosking@gmail.com>                            *
 C*                                                                     *
 C*  Version 2.0    April 2013                                          *
 C*                                                                     *
+C*  Version 2.9    June 2020                                           *
+C*  * Removed the "sanity check" that restricted higher-order          *
+C*    L-moments to be no greater than l_2 in absoulte value.           *
+C*                                                                     *
 C***********************************************************************
 C
 C  Sample L-moments of a data array
@@ -82,9 +86,9 @@ C
 C
 C         Sanity check: higher-order L-moments cannot exceed l_2
 C
-      DO 70 J=3,NMOM
-        IF (ABS(XMOM(J)).GT.XMOM(2)) XMOM(J)=SIGN(XMOM(2),XMOM(J))
-   70 CONTINUE
+C     DO 70 J=3,NMOM
+C       IF (ABS(XMOM(J)).GT.XMOM(2)) XMOM(J)=SIGN(XMOM(2),XMOM(J))
+C  70 CONTINUE
 C
 C         L-moments or L-moment ratios
 C
